utils::globalVariables(
  c(
    ".",
    "V1",
    "V2",
    "V3",
    "V4",
    "V5",
    "V6",
    "V7",
    "V8",
    "V9",
    "V10",
    "V11",
    "V12",
    "V13",
    "Place",
    "Name",
    "Bib_Number",
    "Age",
    "Birthdate",
    "Team",
    "Finals_Result",
    "Prelims_Result",
    "Points",
    "Wind_Speed",
    "Notes",
    "Tiebreaker",
    "Row_Numb",
    "Event",
    "read_html",
    "Event_Row_Min",
    "Row_Min",
    "Row_Max",
    "Row_Fill",
    "Row_Numb_2",
    "as_lines_list_2",
    "DQ",
    "Heat",
    "Exhibition",
    "Results_String",
    "Results_Specials_String",
    "Age_String",
    "Name_String",
    "Tiebreaker_String",
    "minimum_row",
    "rounds",
    "round_attempts",
    "split_attempts",
    ":=",
    "wide_format_vertical",
    "wide_format_horizontal",
    "wide_format_distance",
    "wide_format",
    "wide_format_clean",
    "Time",
    "id",
    "Split_Distance",
    "Split_Time",
    "df",
    "Gender",
    "Round",
    "Result",
    "Wind",
    "Standard",
    "link",
    "Location",
    "Meet_Link",
    "Date",
    "Event_Date",
    "Meet_Date",
    "where",
    "Input",
    "Meet",
    "Best",
    "Height",
    "relay_athletes",
    "splits",
    "split_length"
  )
)
